#!/bin/sh

paths="/opt/kaspersky/kes4lwks /etc/opt/kaspersky/kes4lwks /var/log/kaspersky/kes4lwks /var/run/kes4lwks-samba /var/run/kes4lwks /var/opt/kaspersky/kes4lwks /etc/opt/kaspersky/kes4lwks-supervisor.conf /tmp/kes4lwks.lock.0"
clean_ifempty_paths="/etc/opt/kaspersky"
app="Kaspersky Endpoint Security 8 for Linux"

if [ "$1" != "--confirm-delete" ]
then
    echo
    echo "The script deletes all files and directories left after"
    echo "\"$app\" application"
    echo "package deinstallation."
    echo
    echo "In case of user confirmation (below) ALL data of the application will be"
    echo "deleted, including but not limited to: configuration files, log files,"
    echo "quarantined files, AV-signatures, etc."
    echo

    #
    # Display dirs to be removed
    #
    echo "The following items will be removed:"
    for path in $paths
    do
        if [ -d "$path" ] ; then
            echo "  Directory $path/"
        elif [ -S "$path" ] ; then
            echo "  Socket $path"
        elif [ -f "$path" ] ; then
            echo "  File $path"
        else
            # skip files and dirs what not exists already
            continue
        fi
    done

    echo

    #
    # User confirmation required to delete all
    #
    while :
    do
        echo "Do you want to delete ALL \"$app\""
        echo -n "application data (yes/no)? [no]: "

        read answer

        [ -z "$answer" ] && answer=no

        if [ "$answer" = "no" ] ; then
            echo
            echo "Canceled."
            exit 1
        elif [ "$answer" = "yes" ] ; then
            break
        else
            echo
            echo "Please answer either 'yes' or 'no'."
        fi
    done
fi

echo
echo "Delete \"$app\" data:"

for path in $paths
do
    if [ -d "$path" ] ; then
        rm -rf "$path" || exit 1
        echo "  Directory $path/ is removed."

    elif [ -S "$path" ] ; then
        rm -f "$path" || exit 1
        echo "  Socket $path is removed."

    elif [ -f "$path" ] ; then
        rm -f "$path" || exit 1
        echo "  File $path is removed."

    fi
done
for path in $clean_ifempty_paths
do
    if [ -d "$path" ] ; then
		if [ "$(ls -A $path)" ]; then
			echo "$path is not empty. Skipping it."
		else
			rm -rf "$path" || exit 1
			echo "  Directory $path/ is removed."
		fi
    fi
done

