
/*  
 * This source file is a part of a Kaspersky Antivirus Monitor.
 * Copyright (C) Kaspersky Lab, 1997-2010
 * See License.txt for details
 *
 */


#ifndef KAVMON_FILES_H
#define KAVMON_FILES_H

extern struct vfsmount  *orig_rootmnt;
extern struct dentry    *orig_root;
extern spinlock_t * my_vfsmount_lock;

char * d_path_wrap(struct dentry *dentry, struct vfsmount *vfsmnt,
        char *buf, int buflen);
char* get_path_by_dentry(struct dentry *dentry, struct vfsmount *mnt, int *err, char **fname_part);
char * get_exec_path(struct task_struct *task, file_info * file);
int get_exec_info(struct task_struct *task, file_info * file);
char * get_file_from_userspace (const char * u_filename, file_info * info, char ** filename);
void get_current_fs_root(struct vfsmount **rootmnt, struct dentry **root);
int same_as_current_fs_root(struct vfsmount *rootmnt, struct dentry *root);


static inline void fill_file_info(struct dentry * dentry, file_info * info)
{
	info->dev	=	kdev_t_to_nr(dentry->d_inode->i_sb->s_dev);
	info->ino	=	dentry->d_inode->i_ino;
	info->p_ino	=	dentry->d_parent->d_inode->i_ino;
	info->size	=	dentry->d_inode->i_size;
	info->n_links	=	dentry->d_inode->i_nlink;
	info->m_time	=	dentry->d_inode->i_mtime;
	info->c_time	=	dentry->d_inode->i_ctime;
}

static inline int inode_need_notify(struct inode *inode)
{ /* 0x62656572 - SYSFS - no define in system headers. */
    if(!inode->i_sb) return 0;

    if (inode->i_sb->s_magic==0x62656572 ||
            inode->i_sb->s_magic==DEVFS_SUPER_MAGIC ||
            inode->i_sb->s_magic==PROC_SUPER_MAGIC) return 0;

    if(S_ISREG(inode->i_mode)) {
        if(!inode->i_size) return 0;
    } else if(!S_ISDIR(inode->i_mode)) return 0;

    return 1;
}

static inline int file_need_check(struct dentry *dentry)
{ /* 0x62656572 - SYSFS - no define in system headers. */
    if (dentry->d_inode->i_sb->s_magic==0x62656572 ||
            dentry->d_inode->i_sb->s_magic==DEVFS_SUPER_MAGIC ||
            dentry->d_inode->i_sb->s_magic==PROC_SUPER_MAGIC ||
            !S_ISREG(dentry->d_inode->i_mode)) return 0;

    return 1;
}

static inline int file_unlinked(struct dentry *dentry)
{
	return 0 != (dentry->d_flags & DCACHE_UNHASHED);
}

#endif


